#ifndef NT2_INCLUDE_FUNCTIONS_COMPAN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMPAN_HPP_INCLUDED

#include <nt2/polynom/include/functions/compan.hpp>

#endif
